import { Buff, Bytes } from '@cmdcode/buff-utils';
import { Field, Point } from './ecc.js';
type KeyType = 'ecdsa' | 'schnorr';
type KeyOptions = Partial<KeyConfig>;
interface KeyConfig {
    type: KeyType;
    xonly: boolean;
}
export declare class SecretKey extends Uint8Array {
    static random(opt?: KeyOptions): SecretKey;
    readonly config: KeyConfig;
    constructor(secret: Bytes, options?: KeyOptions);
    get buff(): Buff;
    get raw(): Uint8Array;
    get hex(): string;
    get field(): Field;
    get point(): Point;
    get pub(): PublicKey;
    get hasEvenY(): boolean;
    get hasOddY(): boolean;
    get xfilter(): SecretKey;
    add(bytes: Bytes): SecretKey;
    sub(bytes: Bytes): SecretKey;
    mul(bytes: Bytes): SecretKey;
    div(bytes: Bytes): SecretKey;
    pow(bytes: Bytes): SecretKey;
    negate(): SecretKey;
    sign(message: Bytes, type?: KeyType): Promise<Uint8Array>;
    verify(signature: Bytes, message: Bytes, type?: KeyType): Promise<boolean>;
}
export declare class PublicKey extends Uint8Array {
    static random(opt: KeyOptions): PublicKey;
    static fromSecret(bytes: Bytes, opt: KeyOptions): PublicKey;
    static xOnly: (bytes: Bytes) => Buff;
    readonly config: KeyConfig;
    constructor(pubkey: Bytes, options?: KeyOptions);
    get buff(): Buff;
    get raw(): Uint8Array;
    get hex(): string;
    get point(): Point;
    get buffX(): Buff;
    get rawX(): Uint8Array;
    get hexX(): string;
    get hasEvenY(): boolean;
    get hasOddY(): boolean;
    add(bytes: Bytes): PublicKey;
    sub(bytes: Bytes): PublicKey;
    mul(bytes: Bytes): PublicKey;
    negate(): PublicKey;
    verify(signature: Bytes, message: Bytes, type?: KeyType): Promise<boolean>;
}
export declare const KeyPair: typeof SecretKey;
export {};
//# sourceMappingURL=keypair.d.ts.map